@@ -2,7 +2,7 @@
 #
 #  File: afl-cov
 #
-#  Version: 0.6
+#  Version: 0.6.1
 #
 #  Purpose: Perform lcov coverage diff's against each AFL queue file to see
 #           new functions and line coverage evolve from an AFL fuzzing cycle.
@@ -44,7 +44,7 @@ try:
 except ImportError:
     import subprocess
 
-__version__ = '0.6'
+__version__ = '0.6.1'
 
 NO_OUTPUT   = 0
 WANT_OUTPUT = 1
@@ -510,7 +510,7 @@ def search_cov(cargs):
                 if cargs.src_file:
                     if cargs.src_file == src_file:
                         logr("[+] Function '%s' in file: '%s' executed by: '%s', cycle: %s" \
-                                % (val, current_file, id_file, cycle_num),
+                                % (val, src_file, id_file, cycle_num),
                                 log_file, cargs)
                         search_rv = True
                 else:
@@ -523,7 +523,7 @@ def search_cov(cargs):
                     and cargs.line_search and val == cargs.line_search:
                 if cargs.src_file == src_file:
                     logr("[+] Line '%s' in file: '%s' executed by: '%s', cycle: %s" \
-                            % (val, current_file, id_file, cycle_num),
+                            % (val, src_file, id_file, cycle_num),
                             log_file, cargs)
                     search_rv = True
 
@@ -564,6 +564,8 @@ def lcov_gen_coverage(cov_paths, cargs):
     lcov_opts = ''
     if cargs.enable_branch_coverage:
         lcov_opts += ' --rc lcov_branch_coverage=1'
+    if cargs.follow:
+        lcov_opts += ' --follow'
 
     run_cmd(cargs.lcov_path \
             + lcov_opts
@@ -889,16 +891,16 @@ def is_gcov_enabled(cargs):
                 continue
             if (which(part)):
                 found_exec = True
-                if is_bin_gcov_enabled(part, cargs):
+                if not cargs.disable_gcov_check and is_bin_gcov_enabled(part, cargs):
                     found_code_cov_binary = True
-                break
+                    break
 
         if not found_exec:
             print "[*] Could not find an executable binary " \
                     "--coverage-cmd '%s'" % cargs.coverage_cmd
             return False
 
-        if not found_code_cov_binary:
+        if not cargs.disable_gcov_check and not found_code_cov_binary:
             print "[*] Could not find an executable binary with code " \
                     "coverage support ('-fprofile-arcs -ftest-coverage') " \
                     "in --coverage-cmd '%s'" % cargs.coverage_cmd
@@ -1104,6 +1106,8 @@ def parse_cmdline():
             help="top level AFL fuzzing directory")
     p.add_argument("-c", "--code-dir", type=str,
             help="Directory where the code lives (compiled with code coverage support)")
+    p.add_argument("-f", "--follow", action='store_true',
+            help="Follow links when searching .da files", default=False)
     p.add_argument("-O", "--overwrite", action='store_true',
             help="Overwrite existing coverage results", default=False)
     p.add_argument("--disable-cmd-redirection", action='store_true',
@@ -1139,6 +1143,9 @@ def parse_cmdline():
     p.add_argument("--gcov-check-bin", type=str,
             help="Test a specific binary for code coverage support",
             default=False)
+    p.add_argument("--disable-gcov-check", type=str,
+            help="Disable check for code coverage support",
+            default=False)
     p.add_argument("--background", action='store_true',
             help="Background mode - if also in --live mode, will exit when the alf-fuzz process is finished",
             default=False)
